
use strict;
use warnings;

use Module::Build 0.3601;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.3601",
    "Test::More" => "0.96"
  },
  "configure_requires" => {
    "Module::Build" => "0.3601"
  },
  "dist_abstract" => "PSGI server with built-in HTTPS support, Unix sockets, preforking",
  "dist_author" => [
    "Steven Haryanto <stevenharyanto\@gmail.com>"
  ],
  "dist_name" => "Gepok",
  "dist_version" => "0.22",
  "license" => "perl",
  "module_name" => "Gepok",
  "recommends" => {},
  "recursive_test_files" => 1,
  "requires" => {
    "Class::XSAccessor" => 0,
    "File::HomeDir" => 0,
    "HTTP::Daemon" => 0,
    "HTTP::Daemon::SSL" => 0,
    "HTTP::Daemon::UNIX" => "0.03",
    "HTTP::Daemon::patch::ipv6" => 0,
    "HTTP::Date" => 0,
    "HTTP::Status" => 0,
    "IO::Scalar" => 0,
    "Log::Any" => 0,
    "Moo" => 0,
    "Plack" => 0,
    "SHARYANTO::Proc::Daemon::Prefork" => "0.05",
    "URI::Escape" => 0,
    "perl" => "5.010000"
  },
  "script_files" => []
);


my $build = Module::Build->new(%module_build_args);

$build->create_build_script;
